@@ -1,5 +1,4 @@
 from django.conf import settings
-from django.contrib.auth.models import User
 from django.contrib.sites.models import RequestSite
 from django.core import signing
 from django.core.mail import send_mail
@@ -9,6 +8,7 @@ from django.template.loader import render_to_string
 from django.utils.encoding import force_text
 from django.views import generic
 
+from ..utils import get_user_model
 from .forms import RegistrationForm
 
 
@@ -28,6 +28,9 @@ class Activate(generic.TemplateView):
                                                 salt='le_social.registration')
         except signing.BadSignature:
             return super(Activate, self).dispatch(request, *args, **kwargs)
+        self.request = request
+        self.args = args
+        self.kwargs = kwargs
         self.activate()
         return redirect(self.get_success_url())
 
@@ -38,7 +41,8 @@ class Activate(generic.TemplateView):
         return force_text(self.success_url)
 
     def activate(self):
-        User.objects.filter(pk=self.activation_key).update(is_active=True)
+        get_user_model().objects.filter(
+            pk=self.activation_key).update(is_active=True)
 
 
 class Register(generic.FormView):
